==> gitlab_12.6.4.orig.tar.gz: gitlab-foss-v12.6.4/spec/lib/rspec_flaky/report_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

describe RspecFlaky::Report, :aggregate_failures do
  let(:a_hundred_days) { 3600 * 24 * 100 }
  let(:collection_hash) do
    {
      a: { example_id: 'spec/foo/bar_spec.rb:2' },
      b: { example_id: 'spec/foo/baz_spec.rb:3', first_flaky_at: (Time.now - a_hundred_days).to_s, last_flaky_at: (Time.now - a_hundred_days).to_s }
    }
  end
  let(:suite_flaky_example_report) do
    {
      '6e869794f4cfd2badd93eb68719371d1': {
        example_id: 'spec/foo/bar_spec.rb:2',
        file: 'spec/foo/bar_spec.rb',
        line: 2,
        description: 'hello world',
        first_flaky_at: 1234,
        last_flaky_at: 4321,
        last_attempts_count: 3,
        flaky_reports: 1,
        last_flaky_job: nil
      }
    }
  end
  let(:flaky_examples) { RspecFlaky::FlakyExamplesCollection.new(collection_hash) }
  let(:report) { described_class.new(flaky_examples) }

  describe '.load' do
    let!(:report_file) do
      Tempfile.new(%w[rspec_flaky_report .json]).tap do |f|
        f.write(JSON.pretty_generate(suite_flaky_example_report))
        f.rewind
      end
    end

    after do
      report_file.close
      report_file.unlink
    end

    it 'loads the report file' do
      expect(described_class.load(report_file.path).flaky_examples.to_h).to eq(suite_flaky_example_report)
    end
  end

  describe '.load_json' do
    let(:report_json) do
      JSON.pretty_generate(suite_flaky_example_report)
    end

    it 'loads the report file' do
      expect(described_class.load_json(report_json).flaky_examples.to_h).to eq(suite_flaky_example_report)
    end
  end

  describe '#initialize' do
    it 'accepts a RspecFlaky::FlakyExamplesCollection' do
      expect { report }.not_to raise_error
    end

    it 'does not accept anything else' do
      expect { described_class.new([1, 2, 3]) }.to raise_error(ArgumentError, "`flaky_examples` must be a RspecFlaky::FlakyExamplesCollection, Array given!")
    end
  end

  it 'delegates to #flaky_examples using SimpleDelegator' do
    expect(report.__getobj__).to eq(flaky_examples)
  end

  describe '#write' do
    let(:report_file_path) { Rails.root.join('tmp', 'rspec_flaky_report.json') }

    before do
      FileUtils.rm(report_file_path) if File.exist?(report_file_path)
    end

    after do
      FileUtils.rm(report_file_path) if File.exist?(report_file_path)
    end

    context 'when RspecFlaky::Config.generate_report? is false' do
      before do
        allow(RspecFlaky::Config).to receive(:generate_report?).and_return(false)
      end

      it 'does not write any report file' do
        report.write(report_file_path)

        expect(File.exist?(report_file_path)).to be(false)
      end
    end

    context 'when RspecFlaky::Config.generate_report? is true' do
      before do
        allow(RspecFlaky::Config).to receive(:generate_report?).and_return(true)
      end

      it 'delegates the writes to RspecFlaky::Report' do
        report.write(report_file_path)

        expect(File.exist?(report_file_path)).to be(true)
        expect(File.read(report_file_path))
          .to eq(JSON.pretty_generate(report.flaky_examples.to_h))
      end
    end
  end

  describe '#prune_outdated' do
    it 'returns a new collection without the examples older than 90 days by default' do
      new_report = flaky_examples.to_h.dup.tap { |r| r.delete(:b) }
      new_flaky_examples = report.prune_outdated

      expect(new_flaky_examples).to be_a(described_class)
      expect(new_flaky_examples.to_h).to eq(new_report)
      expect(flaky_examples).to have_key(:b)
    end

    it 'accepts a given number of days' do
      new_flaky_examples = report.prune_outdated(days: 200)

      expect(new_flaky_examples.to_h).to eq(report.to_h)
    end
  end
end

==> gitlab_12.8.8.orig.tar.gz: gitlab-foss-v12.8.8/spec/lib/rspec_flaky/report_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

describe RspecFlaky::Report, :aggregate_failures do
  let(:thirty_one_days) { 3600 * 24 * 31 }
  let(:collection_hash) do
    {
      a: { example_id: 'spec/foo/bar_spec.rb:2' },
      b: { example_id: 'spec/foo/baz_spec.rb:3', first_flaky_at: (Time.now - thirty_one_days).to_s, last_flaky_at: (Time.now - thirty_one_days).to_s }
    }
  end
  let(:suite_flaky_example_report) do
    {
      '6e869794f4cfd2badd93eb68719371d1': {
        example_id: 'spec/foo/bar_spec.rb:2',
        file: 'spec/foo/bar_spec.rb',
        line: 2,
        description: 'hello world',
        first_flaky_at: 1234,
        last_flaky_at: 4321,
        last_attempts_count: 3,
        flaky_reports: 1,
        last_flaky_job: nil
      }
    }
  end
  let(:flaky_examples) { RspecFlaky::FlakyExamplesCollection.new(collection_hash) }
  let(:report) { described_class.new(flaky_examples) }

  describe '.load' do
    let!(:report_file) do
      Tempfile.new(%w[rspec_flaky_report .json]).tap do |f|
        f.write(JSON.pretty_generate(suite_flaky_example_report))
        f.rewind
      end
    end

    after do
      report_file.close
      report_file.unlink
    end

    it 'loads the report file' do
      expect(described_class.load(report_file.path).flaky_examples.to_h).to eq(suite_flaky_example_report)
    end
  end

  describe '.load_json' do
    let(:report_json) do
      JSON.pretty_generate(suite_flaky_example_report)
    end

    it 'loads the report file' do
      expect(described_class.load_json(report_json).flaky_examples.to_h).to eq(suite_flaky_example_report)
    end
  end

  describe '#initialize' do
    it 'accepts a RspecFlaky::FlakyExamplesCollection' do
      expect { report }.not_to raise_error
    end

    it 'does not accept anything else' do
      expect { described_class.new([1, 2, 3]) }.to raise_error(ArgumentError, "`flaky_examples` must be a RspecFlaky::FlakyExamplesCollection, Array given!")
    end
  end

  it 'delegates to #flaky_examples using SimpleDelegator' do
    expect(report.__getobj__).to eq(flaky_examples)
  end

  describe '#write' do
    let(:report_file_path) { Rails.root.join('tmp', 'rspec_flaky_report.json') }

    before do
      FileUtils.rm(report_file_path) if File.exist?(report_file_path)
    end

    after do
      FileUtils.rm(report_file_path) if File.exist?(report_file_path)
    end

    context 'when RspecFlaky::Config.generate_report? is false' do
      before do
        allow(RspecFlaky::Config).to receive(:generate_report?).and_return(false)
      end

      it 'does not write any report file' do
        report.write(report_file_path)

        expect(File.exist?(report_file_path)).to be(false)
      end
    end

    context 'when RspecFlaky::Config.generate_report? is true' do
      before do
        allow(RspecFlaky::Config).to receive(:generate_report?).and_return(true)
      end

      it 'delegates the writes to RspecFlaky::Report' do
        report.write(report_file_path)

        expect(File.exist?(report_file_path)).to be(true)
        expect(File.read(report_file_path))
          .to eq(JSON.pretty_generate(report.flaky_examples.to_h))
      end
    end
  end

  describe '#prune_outdated' do
    it 'returns a new collection without the examples older than 30 days by default' do
      new_report = flaky_examples.to_h.dup.tap { |r| r.delete(:b) }
      new_flaky_examples = report.prune_outdated

      expect(new_flaky_examples).to be_a(described_class)
      expect(new_flaky_examples.to_h).to eq(new_report)
      expect(flaky_examples).to have_key(:b)
    end

    it 'accepts a given number of days' do
      new_flaky_examples = report.prune_outdated(days: 32)

      expect(new_flaky_examples.to_h).to eq(report.to_h)
    end
  end
end
